@@ -20,7 +20,7 @@
 
 #define RRTYPE_AMTRELAY_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_amtrelay(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -116,12 +116,11 @@ fromtext_amtrelay(ARGS_FROMTEXT) {
 		return (dns_name_fromtext(&name, &buffer, origin, options,
 					  target));
 	default:
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_amtrelay(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
@@ -178,13 +177,12 @@ totext_amtrelay(ARGS_TOTEXT) {
 		return (dns_name_totext(&name, false, target));
 
 	default:
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_amtrelay(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t region;
@@ -236,7 +234,7 @@ fromwire_amtrelay(ARGS_FROMWIRE) {
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_amtrelay(ARGS_TOWIRE) {
 	isc_region_t region;
 
@@ -249,7 +247,7 @@ towire_amtrelay(ARGS_TOWIRE) {
 	return (mem_tobuffer(target, region.base, region.length));
 }
 
-static inline int
+static int
 compare_amtrelay(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -266,7 +264,7 @@ compare_amtrelay(ARGS_COMPARE) {
 	return (isc_region_compare(&region1, &region2));
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_amtrelay(ARGS_FROMSTRUCT) {
 	dns_rdata_amtrelay_t *amtrelay = source;
 	isc_region_t region;
@@ -306,7 +304,7 @@ fromstruct_amtrelay(ARGS_FROMSTRUCT) {
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_amtrelay(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_amtrelay_t *amtrelay = target;
@@ -370,7 +368,7 @@ tostruct_amtrelay(ARGS_TOSTRUCT) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline void
+static void
 freestruct_amtrelay(ARGS_FREESTRUCT) {
 	dns_rdata_amtrelay_t *amtrelay = source;
 
@@ -392,7 +390,7 @@ freestruct_amtrelay(ARGS_FREESTRUCT) {
 	amtrelay->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_amtrelay(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_amtrelay);
 
@@ -403,7 +401,7 @@ additionaldata_amtrelay(ARGS_ADDLDATA) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_amtrelay(ARGS_DIGEST) {
 	isc_region_t region;
 
@@ -413,7 +411,7 @@ digest_amtrelay(ARGS_DIGEST) {
 	return ((digest)(arg, &region));
 }
 
-static inline bool
+static bool
 checkowner_amtrelay(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_amtrelay);
 
@@ -425,7 +423,7 @@ checkowner_amtrelay(ARGS_CHECKOWNER) {
 	return (true);
 }
 
-static inline bool
+static bool
 checknames_amtrelay(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_amtrelay);
 
@@ -436,7 +434,7 @@ checknames_amtrelay(ARGS_CHECKNAMES) {
 	return (true);
 }
 
-static inline int
+static int
 casecompare_amtrelay(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
