@@ -18,7 +18,7 @@
 
 #define RRTYPE_X25_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_x25(ARGS_FROMTEXT) {
 	isc_token_t token;
 	unsigned int i;
@@ -46,7 +46,7 @@ fromtext_x25(ARGS_FROMTEXT) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_x25(ARGS_TOTEXT) {
 	isc_region_t region;
 
@@ -59,7 +59,7 @@ totext_x25(ARGS_TOTEXT) {
 	return (txt_totext(&region, true, target));
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_x25(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	unsigned int i;
@@ -83,7 +83,7 @@ fromwire_x25(ARGS_FROMWIRE) {
 	return (txt_fromwire(source, target));
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_x25(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
@@ -93,7 +93,7 @@ towire_x25(ARGS_TOWIRE) {
 	return (mem_tobuffer(target, rdata->data, rdata->length));
 }
 
-static inline int
+static int
 compare_x25(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -109,7 +109,7 @@ compare_x25(ARGS_COMPARE) {
 	return (isc_region_compare(&r1, &r2));
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_x25(ARGS_FROMSTRUCT) {
 	dns_rdata_x25_t *x25 = source;
 	uint8_t i;
@@ -137,7 +137,7 @@ fromstruct_x25(ARGS_FROMSTRUCT) {
 	return (mem_tobuffer(target, x25->x25, x25->x25_len));
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_x25(ARGS_TOSTRUCT) {
 	dns_rdata_x25_t *x25 = target;
 	isc_region_t r;
@@ -162,7 +162,7 @@ tostruct_x25(ARGS_TOSTRUCT) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline void
+static void
 freestruct_x25(ARGS_FREESTRUCT) {
 	dns_rdata_x25_t *x25 = source;
 
@@ -179,7 +179,7 @@ freestruct_x25(ARGS_FREESTRUCT) {
 	x25->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_x25(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_x25);
 
@@ -190,7 +190,7 @@ additionaldata_x25(ARGS_ADDLDATA) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_x25(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -201,7 +201,7 @@ digest_x25(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static bool
 checkowner_x25(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_x25);
 
@@ -213,7 +213,7 @@ checkowner_x25(ARGS_CHECKOWNER) {
 	return (true);
 }
 
-static inline bool
+static bool
 checknames_x25(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_x25);
 
@@ -224,7 +224,7 @@ checknames_x25(ARGS_CHECKNAMES) {
 	return (true);
 }
 
-static inline int
+static int
 casecompare_x25(ARGS_COMPARE) {
 	return (compare_x25(rdata1, rdata2));
 }
