@@ -1,9 +1,11 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * License, v. 2.0.  If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -22,20 +24,18 @@
 #define HAVE_GET_WIN32_NAMESERVERS 1
 
 #include "../resconf.c"
-
 #include <iphlpapi.h>
 
 #define TCPIP_SUBKEY "SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters"
 
 isc_result_t
-get_win32_searchlist(irs_resconf_t *conf)
-{
+get_win32_searchlist(irs_resconf_t *conf) {
 	isc_result_t result = ISC_R_SUCCESS;
-	HKEY	     hKey;
-	char	     searchlist[MAX_PATH];
-	DWORD	     searchlen = MAX_PATH;
-	LSTATUS	     status;
-	char *	     cp;
+	HKEY hKey;
+	char searchlist[MAX_PATH];
+	DWORD searchlen = MAX_PATH;
+	LSTATUS status;
+	char *cp;
 
 	REQUIRE(conf != NULL);
 
@@ -65,12 +65,11 @@ get_win32_searchlist(irs_resconf_t *conf)
 }
 
 isc_result_t
-get_win32_nameservers(irs_resconf_t *conf)
-{
-	isc_result_t	result;
-	FIXED_INFO *	FixedInfo;
-	ULONG		BufLen = sizeof(FIXED_INFO);
-	DWORD		dwRetVal;
+get_win32_nameservers(irs_resconf_t *conf) {
+	isc_result_t result;
+	FIXED_INFO *FixedInfo;
+	ULONG BufLen = sizeof(FIXED_INFO);
+	DWORD dwRetVal;
 	IP_ADDR_STRING *pIPAddr;
 
 	REQUIRE(conf != NULL);
